@@ -21,6 +21,9 @@ def download_files():
 
 print("***** If you dont have any images or config files feel free to use mine at 'https://github.com/timo42453189/car_drive_ai_files' *****")
 print("***** if you have no images just call the download_files methode *****")
+print("***** There are some arguments for the run function *****")
+print("***** w_size=() is the window size, c_size=() is the size of the car, c_speed=8 is the car speed *****")
+print("***** config_file='path/to/config_file', d=True/False to download sample tracks, car images and config file *****")
 
 pygame.init()
 pygame.font.init()
